@@ -1,15 +1,24 @@
-from rdflib import Graph, URIRef, Literal, Namespace
+from rdflib import Graph, URIRef, Literal, Namespace, XSD
 import pandas as pd
 import validators
 
 from uuid import uuid4
 import re
+from datetime import datetime
 
 
 def is_curie(value):
     return re.fullmatch('\\S+:\\S+', value)
 
 
+def is_datetime(value):
+    return re.fullmatch('^(-?(?:[1-9][0-9]*)?[0-9]{4})-(1[0-2]|0[1-9])-(3[01]|0[1-9]|[12][0-9])T(2[0-3]|[01][0-9]):([0-5][0-9]):([0-5][0-9])(\.[0-9]+)?(Z|[+-](?:2[0-3]|[01][0-9]):[0-5][0-9])?$', value)
+
+
+def is_date(value):
+    return re.fullmatch('^([1-9][0-9]{3})-(1[0-2]|0[1-9])-(3[01]|0[1-9]|[12][0-9])?$', value)
+
+
 def _get_prefixes(df):
     prefixes = dict()
     base_uri = None
@@ -41,10 +50,16 @@ def _generate_uri(base_uri):
 
 def _add_object(value, prefixes):
     if not pd.isnull(value) and type(value) == str and value.__contains__(':'):
-        if validators.url(value):
+        if is_datetime(value):
+            return Literal(value, datatype=XSD.dateTime)
+        elif is_date(value):
+            return Literal(value, datatype=XSD.date)
+        elif validators.url(value):
             return URIRef(value)
         elif is_curie(value):
             return _resolve_curie(value, prefixes)
+        else:
+            pass
 
     return Literal(value)
 
